Documentation
¶
Index ¶
Constants ¶
const Iterations = 128
Iterations is the number of iterations used in the DLN proof for soundness.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Proof ¶
type Proof struct {
Alpha,
T [Iterations]*big.Int
}
Proof is a zero-knowledge proof of knowledge of the discrete logarithm over a safe prime product.
func NewDLNProof ¶
NewDLNProof creates a new DLN proof that h2 = h1^x mod N given the factorization N = p*q.
func UnmarshalDLNProof ¶
UnmarshalDLNProof reconstructs a DLN Proof from a slice of byte slices.
Click to show internal directories.
Click to hide internal directories.