Documentation
¶
Index ¶
Constants ¶
const ( // Iterations is the number of iterations used in the modular proof for soundness. Iterations = 80 // ProofModBytesParts is the number of byte parts in a serialized ProofMod. ProofModBytesParts = Iterations*2 + 3 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProofMod ¶
type ProofMod struct {
W *big.Int
X [Iterations]*big.Int
A *big.Int
B *big.Int
Z [Iterations]*big.Int
}
ProofMod is a zero-knowledge proof that N is a product of two primes (Paillier-Blum modulus proof).
func NewProofFromBytes ¶
NewProofFromBytes reconstructs a ProofMod from a slice of byte slices.
func (*ProofMod) Bytes ¶
func (pf *ProofMod) Bytes() [ProofModBytesParts][]byte
Bytes serializes the proof into a fixed-size array of byte slices.
func (*ProofMod) ValidateBasic ¶
ValidateBasic checks that all fields of the proof are non-nil.
Click to show internal directories.
Click to hide internal directories.